dnl =====================================================================
dnl =====================================================================
AC_DEFUN([AX_MATLAB_SEARCH_DIR],[dnl
  ax_matlab_prefixes="MATLAB_R MATLAB matlab_r"
  case x$1 in
  x|xno)
    dnl ::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
    dnl   Caller requested no matlab support
    dnl ::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
    ;;
  xcheck|xyes)
    dnl ::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
    dnl   Check for matlab in well known system locations
    dnl ::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
    for ax_dir in /Applications /ldcg
    do
      if test ! -d $ax_dir
      then
        continue
      fi
      for ax_matlab_ver in $ax_matlab_versions
      do
	for ax_matlab_prefix in $ax_matlab_prefixes
	do
	  if test -d $ax_dir/${ax_matlab_prefix}${ax_matlab_ver}
	  then
	    ax_matlab_paths="$ax_matlab_paths $ax_dir/${ax_matlab_prefix}${ax_matlab_ver}"
	    break
          elif test -d $ax_dir/${ax_matlab_prefix}${ax_matlab_ver}.app
	  then
	    ax_matlab_paths="$ax_matlab_paths $ax_dir/${ax_matlab_prefix}${ax_matlab_ver}.app"
	    break
	  fi
	done
      done
    done
    ;;
  x*:*)
    dnl ::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
    dnl  Caller specified the parent directories for the versions
    dnl    of matlab to be compiled
    dnl ::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
    ax_matlab_paths=`echo $1 | sed -e 's/:/ /g'`
    ;;
  *)
    dnl ::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
    dnl  This may be the parent or grandparent directory of matlab
    dnl    installations(s).
    dnl ::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
    if test -d $1
    then
      if test -f $1/bin/matlab
      then
        ax_matlab_paths=$1
      else
	for ax_matlab_ver in $ax_matlab_versions
	do
	  for ax_matlab_prefix in $ax_matlab_prefixes
	  do
	    if test -d $1/${ax_matlab_prefix}${ax_matlab_ver}
	    then
	      ax_matlab_paths="$ax_matlab_paths $1/${ax_matlab_prefix}${ax_matlab_ver}"
	      break
	    fi
	  done
	done
      fi
    fi
    ;;
  esac
  AC_MSG_CHECKING([for matlab installations])
  if test -z "$ax_matlab_paths"
  then
    AC_MSG_RESULT([<none>])
  else
    AC_MSG_RESULT($ax_matlab_paths)
  fi
])
dnl =====================================================================
dnl  AC_PACKAGE_MATLAB_SUITE
dnl =====================================================================
AC_DEFUN([AX_ML_PACKAGE_MATLAB_SUITE],[dnl
	AC_PATH_PROG(PKGCONFIG,pkg-config)
	NDSCLIENT_MATLAB_VERSIONS
	dnl--------------------------------------------------------------
	dnl Get the current list of matlab version to try
	dnl--------------------------------------------------------------
	AC_ARG_WITH([matlab],
	  [AS_HELP_STRING([--with-matlab@<:@=DIR@:>@],
	    [colon separated list of root directories of matlab or grandparent directory of multiple matlab installations @<:@default=check@:>@])],
	    [],
	    [with_matlab="check"])
	dnl -------------------------------------------------------------
	dnl  
	dnl -------------------------------------------------------------
	AX_MATLAB_SEARCH_DIR($with_matlab)
	case $with_matlab in
	no)
	  dnl -----------------------------------------------------------
	  dnl  This is the case where matlab has been disabled
	  dnl -----------------------------------------------------------
	  ;;
	check)
	  dnl -----------------------------------------------------------
	  dnl  This is the case where the system defaults are scanned
	  dnl    for multiple matlab installations
	  dnl -----------------------------------------------------------
	  ;;
	*:*)
	  dnl -----------------------------------------------------------
	  dnl  This is the case where the user has specified specific
	  dnl    instances of matlab to be searched.
	  dnl -----------------------------------------------------------
	  ;;
	*)
	  dnl -----------------------------------------------------------
	  dnl  This is either a single instance of matlab or the
	  dnl    grandparent directory of multiple instances.
	  dnl -----------------------------------------------------------
	  ;;
	esac
	AC_CHECK_SIZEOF(long)
	AC_COMPILE_IFELSE([dnl
	  AC_LANG_PROGRAM([],[dnl
	    #if SIZEOF_LONG == 8
	    This will not compile.
	    #endif])
	],[ax_ccmex_compiler_mode=32bit],[ax_ccmex_compiler_mode=64bit])
	dnl--------------------------------------------------------------
	dnl Check to see if 64bit mode was requested
	dnl--------------------------------------------------------------
	case $ax_ccmex_compiler_mode in
  	32bit)
	  matlab_mk_pkg_config_opts="${matlab_mk_pkg_config_opts} --32bit"
	  ;;
  	64bit)
	  matlab_mk_pkg_config_opts="${matlab_mk_pkg_config_opts} --64bit"
	  case "`uname -m`" in
	  i386)
	    if test "`uname `" = "Darwin"
 	    then
	      suffix=""
	    else
	      suffix="/x86_64"
	    fi
	    ;;
	  *)
	    suffix=""
	    ;;
	  esac
	  libdir="${libdir}${suffix}"
	  ;;
	esac
	dnl--------------------------------------------------------------
	dnl 
	dnl--------------------------------------------------------------
	for ax_matlab_dir in $ax_matlab_paths
	do
	  if test ! -d ${ax_matlab_dir}/bin
	  then
	    continue
	  fi
	  ax_matlab_ver=`$ax_matlab_dir/bin/matlab -nojvm -nosplash -nodisplay < /dev/null | grep -i Version | sed -e 's/^.* Release //' -e 's/^.*[[(]]R\([[^)]]*\)[[)]].*$/\1/'`
	  if test -z "$ax_matlab_ver"
	  then
	    continue
	  fi
	  if test ! -d lib
	  then
	    mkdir lib
	  fi
	  if test ! -d lib/pkgconfig
	  then
	    mkdir lib/pkgconfig
	  fi
	  AC_MSG_CHECKING([the usability of matlab release $ax_matlab_ver in $ax_matlab_dir])
	  ${srcdir}/config/matlab-mk-pkg-config ${matlab_mk_pkg_config_opts} ${ax_matlab_dir} > lib/pkgconfig/matlab_${ax_matlab_ver}.pc
	  if test $? = 0
  	  then
	    ax_matlab_supported_ver="${ax_matlab_supported_ver} ${ax_matlab_ver}"
	    AC_MSG_RESULT([yes])
	  else
	    AC_MSG_RESULT([no])
	  fi
	done
	MATLAB_VERSIONS=${ax_matlab_supported_ver}
	AC_SUBST(MATLAB_VERSIONS)
	dnl---------------------------------------------------------------
	dnl 
	dnl---------------------------------------------------------------
	NDSCLIENT_MATLAB_CONDITIONALS
])
