#========================================================================
# NOTES:
#    The octave default is to check for a system supplied package.
#    The matlab default is to check /ldcg for directories of the form
#       matlab_r<ver>.
#
# MATLAB override:
#    You can specify to build no matlab packages by specifying
#      --without matlab
#    when invoking rpmbuild.
#    If your matlab packages are rooted in a directory other than /ldcg,
#    then you must specify
#      --with matlab --define '_matlab_base_dir <dir>'
#    when invoking matlab.
#      <dir> is the parent directory of the matlab packages.
#
# OCTIVE override:
#    You can specify to build without octive support by specifying
#      --without octive
#    when invoking rpmbuild.
#========================================================================
%define name 	nds2-client
%define version 0.8.0
%define release 1
%define daswg   /opt/lscsoft
%define _prefix  %{daswg}/nds2-client
%define _sysconfdir %{_prefix}/etc

%define _use_internal_dependency_generator 0
%define __find_requires %{_builddir}/%{name}-%{version}/config/nds-find-requires

#::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
# Sanity checks
#::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
%{?_with_matlab: %{?_without_matlab: %{error: both _with_matlab and _without_matlab}}}
%{?_with_octave: %{?_without_octave: %{error: both _with_octave and _without_octave}}}

%if %{?_with_matlab:1}%{!?_with_matlab:0}
%if %{?_matlab_base_dir:1}%{!?_matlab_base_dir:0}
%define _matlab_configure_option --with-matlab=%{_matlab_base_dir}
%else
%define _matlab_configure_option --with-matlab
%endif
%else
%define _matlab_configure_option %{nil}
%endif
#========================================================================
# Main spec file
#========================================================================
Name: 		%{name}
Summary: 	NDS2 Client interface
Version: 	%{version}
Release: 	%{release}
License: 	GPL
Group: 		LSC Software/Data Analysis
Source: 	%{name}-%{version}.tar.gz
Packager: 	John Zweizig (john.zweizig@ligo.org)
BuildRoot: 	%{_tmppath}/%{name}-%{version}-root
URL: 		https://www.lsc-group.phys.uwm.edu/daswg/wiki/NetworkDataServer2
BuildRequires: 	gcc, gcc-c++, glibc, automake, autoconf, libtool, m4, make
Summary: 	DMT offline
Provides: 	%name
Obsoletes:	%name < %version
Prefix:		%_prefix

%description
The NDS2 client interface allow the user to down-load LIGO data from the V2 LIGO Network Data Servers.

%package devel
Group: Development/Scientific
Summary: NDS2 development
Requires: nds2-client-headers
%description devel
This allows for development using the nds2 client protocol.

%package matlab-devel
Group: Development/Scientific
Summary: NDS2 matlab development
Requires: nds2-client-devel
%description matlab-devel
This allows for generic or custom MATLAB development.

%package octave
Group: Development/Scientific
Summary: Octave extensions for NDS2
Requires: nds2-client
%description octave
This provides extensions to octave to access an NDS2 server

%package matlab2011b
Group: Development/Scientific
Summary: MATLAB 2011b extensions for NDS2
Requires: nds2-client
%description matlab2011b
This provides extensions to MATLAB 2011b to access an NDS2 server

%package matlab2011a
Group: Development/Scientific
Summary: MATLAB 2011a extensions for NDS2
Requires: nds2-client
%description matlab2011a
This provides extensions to MATLAB 2011a to access an NDS2 server

%package matlab2010b
Group: Development/Scientific
Summary: MATLAB 2010b extensions for NDS2
Requires: nds2-client
%description matlab2010b
This provides extensions to MATLAB 2010b to access an NDS2 server

%package matlab2010a
Group: Development/Scientific
Summary: MATLAB 2010a extensions for NDS2
Requires: nds2-client
%description matlab2010a
This provides extensions to MATLAB 2010a to access an NDS2 server

%package matlab2009b
Group: Development/Scientific
Summary: MATLAB 2009b extensions for NDS2
Requires: nds2-client
%description matlab2009b
This provides extensions to MATLAB 2009b to access an NDS2 server

%package matlab2009a
Group: Development/Scientific
Summary: MATLAB 2009a extensions for NDS2
Requires: nds2-client
%description matlab2009a
This provides extensions to MATLAB 2009a to access an NDS2 server

%package matlab2008b
Group: Development/Scientific
Summary: MATLAB 2008b extensions for NDS2
Requires: nds2-client
%description matlab2008b
This provides extensions to MATLAB 2008b to access an NDS2 server

%package matlab2008a
Group: Development/Scientific
Summary: MATLAB 2008a extensions for NDS2
Requires: nds2-client
%description matlab2008a
This provides extensions to MATLAB 2008a to access an NDS2 server

%package matlab2007b
Group: Development/Scientific
Summary: MATLAB 2007b extensions for NDS2
Requires: nds2-client
%description matlab2007b
This provides extensions to MATLAB 2007b to access an NDS2 server

%package matlab2007a
Group: Development/Scientific
Summary: MATLAB 2007a extensions for NDS2
Requires: nds2-client
%description matlab2007a
This provides extensions to MATLAB 2007a to access an NDS2 server

%package matlab2006b
Group: Development/Scientific
Summary: MATLAB 2006b extensions for NDS2
Requires: nds2-client
%description matlab2006b
This provides extensions to MATLAB 2006b to access an NDS2 server

%package matlab2006a
Group: Development/Scientific
Summary: MATLAB 2006a extensions for NDS2
Requires: nds2-client
%description matlab2006a
This provides extensions to MATLAB 2006a to access an NDS2 server

%package matlabr13
Group: Development/Scientific
Summary: MATLAB r13 extensions for NDS2
Requires: nds2-client
%description matlabr13
This provides extensions to MATLAB r13 to access an NDS2 server

%package headers
Group: Development/Scientific
Summary: NDS2 headers
%description headers
This provides a separate package to install the headers shared by the 64 and 32 bit versions.

#----------------------------------------------
# Get onto the fun of building the NDS software
#----------------------------------------------
%prep
%setup

%build
PKG_CONFIG_PATH=/usr/%{_lib}/pkgconfig
export PKG_CONFIG_PATH
%configure \
	%{?_matlab_configure_option}	\
	%{?_without_matlab}		\
	%{?_with_octave}		\
	%{?_without_octave}

make
make check

%install
rm -rf %{buildroot}
make install DESTDIR=%{buildroot}

#----------------------------------------------
# Remove files that will not be packaged based
# on the arch type
#----------------------------------------------
%ifarch noarch
rm -rf %{buildroot}%{_bindir}
rm -rf %{buildroot}%{_libdir}
%else
rm -rf %{buildroot}%{_includedir}
rm -rf %{buildroot}%{_datadir}/matlab/*
%endif

%ifarch noarch
#----------------------------------------------
# Do the noarch files
#----------------------------------------------
%files headers
%{_includedir}/daqc*.h
%{_includedir}/nds1.h
%{_includedir}/nds2.h
%{_includedir}/channel.h
%{_includedir}/trench.h

%files matlab-devel
%_datadir/matlab/src/*
%_datadir/matlab/NDS*m

%else

#----------------------------------------------
# Handle binary packages
#----------------------------------------------

%if %{?_without_octave:1}%{!?_without_octave:0}
%define octave_installed %(echo 0)
%else
%define octave_installed %(test -e /usr/bin/octave && echo 1 || echo 0)
%endif

%if 0
%if %{?_with_matlab:1}%{!?_with_matlab:0}
%define _matlab_base_dir `echo %{_with_matlab} | sed -e 's/^[^=]*=//g'`
%endif
%endif

%if %{?_without_matlab:1}%{!?_without_matlab:0}
%define matlab_installed() %(echo 0)
%else
%if %{?_matlab_base_dir:1}%{!?_matlab_base_dir:0}
%define matlab_installed() %(test -d %{_matlab_base_dir}/matlab_r%{1} && echo 1 || echo 0)
%else
%define matlab_installed() %(test -d /ldcg/matlab_r%{1} && echo 1 || echo 0)
%endif
%endif

%define matlab_files() %{_libdir}/matlab%{1}

%define platform_64_bit %(echo %{_libdir} | grep 64 && echo 1 || echo 0)

%define matlab_file_section() \
%files matlab%1 \
%{matlab_files %1}

%files
%defattr(-,root,root)
%_bindir/*
%_libdir/lib*.so*
%_sysconfdir/*

%files devel
%_libdir/lib*.a
%_libdir/lib*.la
%_libdir/pkgconfig/nds2-client.pc

#------------------------------------------------------------------------
# Octave
#------------------------------------------------------------------------
%if %{octave_installed}
%files octave
%{_libdir}/octave
%endif
#------------------------------------------------------------------------
# MATLAB
#------------------------------------------------------------------------
# :::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
%define matlabver 2011b
%if %{matlab_installed %{matlabver}}
%files matlab%{matlabver}
%{matlab_files %{matlabver}}
%endif
# :::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
%define matlabver 2011a
%if %{matlab_installed %{matlabver}}
%files matlab%{matlabver}
%{matlab_files %{matlabver}}
%endif
# :::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
%define matlabver 2010b
%if %{matlab_installed %{matlabver}}
%files matlab%{matlabver}
%{matlab_files %{matlabver}}
%endif
# :::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
%define matlabver 2010a
%if %{matlab_installed %{matlabver}}
%files matlab%{matlabver}
%{matlab_files %{matlabver}}
%endif
# :::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
%define matlabver 2009b
%if %{matlab_installed %{matlabver}}
%files matlab%{matlabver}
%{matlab_files %{matlabver}}
%endif
# :::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
%define matlabver 2009a
%if %{matlab_installed %{matlabver}}
%files matlab%{matlabver}
%{matlab_files %{matlabver}}
%endif
# :::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
%define matlabver 2008b
%if %{matlab_installed %{matlabver}}
%files matlab%{matlabver}
%{matlab_files %{matlabver}}
%endif
# :::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
%define matlabver 2008a
%if %{matlab_installed %{matlabver}}
%files matlab%{matlabver}
%{matlab_files %{matlabver}}
%endif
# :::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
%define matlabver 2007b
%if %{matlab_installed %{matlabver}}
%files matlab%{matlabver}
%{matlab_files %{matlabver}}
%endif
# :::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
%define matlabver 2007a
%if %{matlab_installed %{matlabver}}
%files matlab%{matlabver}
%{matlab_files %{matlabver}}
%endif
# :::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
%define matlabver 2006b
%if %{matlab_installed %{matlabver}}
%files matlab%{matlabver}
%{matlab_files %{matlabver}}
%endif
# :::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
%define matlabver 2006a
%if %{matlab_installed %{matlabver}}
%files matlab%{matlabver}
%{matlab_files %{matlabver}}
%endif
# :::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
%define matlabver 13
%if %{matlab_installed %{matlabver}}
%if %{?platform_64_bit:0}%{!?platform_64_bit:1}
%files matlabr%{matlabver}
%{matlab_files %{matlabver}}
%endif

%endif

%endif
